savepoints_dialog library

SavePoints Dialog Library

Provides modern, customizable dialog widgets with glassmorphism design.

Classes

DialogTransitionScope
Caches dialog content so it is built once per show, reducing rebuilds during animation.
HeaderDialog
A dialog with a colored header bar and close button outside the box.
SavePointsDialog
A modern, customizable dialog with glassmorphism design.

Enums

DialogAnimationDirection
Direction for dialog animations
DialogAnimationType
Dialog animation types