SemanticsProperties class

Properties for semantic widgets

Constructors

SemanticsProperties({String? label, String? hint, bool? button, bool? enabled, bool? modal, bool? liveRegion, VoidCallback? onTap})
const

Properties

button bool?
final
enabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
label String?
final
liveRegion bool?
final
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited