SnackbarQueue class

Manages a queue of snackbars to show them one at a time

Constructors

SnackbarQueue()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Checks if queue is empty
no setter
isShowing bool
Checks if a snackbar is currently showing
no setter
length int
Gets the current queue length
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clears the queue
enqueue({required BuildContext context, required String title, String? subtitle, SnackbarType? type, Duration? duration, bool showProgressIndicator = false}) → void
Adds a snackbar to the queue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited