ValidationUtils class

Utility functions for input validation

Constructors

ValidationUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isInRange(double? value, double min, double max) bool
Validates that a double is within a range
isNotEmpty(String? value) bool
Validates that a string is not empty
isPositiveDouble(double? value) bool
Validates that a double is positive
isPositiveDuration(Duration? duration) bool
Validates that a duration is positive
isPositiveInt(int? value) bool
Validates that an integer is positive