AccessibilityUtils class
Utility functions for accessibility features
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
- Creates semantic properties for a button
-
dialogSemantics(
{required String label, required String? hint, bool isModal = true, bool? isButton, VoidCallback? onTap}) → SemanticsProperties - Creates semantic properties for a dialog
-
snackbarSemantics(
{required String label, String? hint, bool isLiveRegion = true, bool isButton = false, VoidCallback? onTap}) → SemanticsProperties - Creates semantic properties for a snackbar
-
withSemantics(
{required Widget child, required SemanticsProperties properties}) → Widget - Wraps a widget with semantic properties