ThemeUtils class
Utility functions for theme-related operations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAdaptiveColor(
BuildContext context, {required Color lightColor, required Color darkColor}) → Color - Gets a color that adapts to the theme
-
getAdaptiveColorWithOpacity(
BuildContext context, {required Color lightColor, required Color darkColor, required double opacity}) → Color - Gets a color with opacity that adapts to theme
-
getColorScheme(
BuildContext context) → ColorScheme - Gets the current color scheme
-
getTheme(
BuildContext context) → ThemeData - Gets the current theme
-
isDark(
BuildContext context) → bool - Determines if the current theme is dark